@@ -194,8 +194,12 @@ PointerList DataStructure::pointerListAll() const
 
 void DataStructure::registerDataType(int identifier)
 {
+    if (d->_dataTypeLists.contains(identifier)) {
+        kWarning() << "DataType already registered: aborting";
+        return;
+    }
     if (!d->_document->dataType(identifier)) {
-        kError() << "DataType not registered at DataStructure: not valid";
+        kError() << "DataType not registered at document: aborting";
         return;
     }
     d->_dataTypeLists.insert(identifier, DataList());
@@ -205,8 +209,12 @@ void DataStructure::registerDataType(int identifier)
 
 void DataStructure::registerPointerType(int identifier)
 {
+    if (d->_pointerTypeLists.contains(identifier)) {
+        kWarning() << "PointerType already registered: aborting";
+        return;
+    }
     if (!d->_document->pointerType(identifier)) {
-        kError() << "PointerType not registered at DataStructure: not valid";
+        kError() << "PointerType not registered at document: aborting";
         return;
     }
     d->_pointerTypeLists.insert(identifier, PointerList());
@@ -214,19 +222,19 @@ void DataStructure::registerPointerType(int identifier)
 }
 
 
-void DataStructure::removeDataType(int dataType)
+void DataStructure::removeDataType(int identifier)
 {
-    if (dataType == 0) {
+    if (identifier == 0) {
         kWarning() << "Could not remove non-existing DataType";
         return;
     }
 
-    foreach(DataPtr data, d->_dataTypeLists[dataType]) {
+    foreach(DataPtr data, d->_dataTypeLists[identifier]) {
         data->remove();
     }
-    d->_dataTypeLists[dataType].clear();
-    d->_dataTypeLists.remove(dataType);
-    d->_dataTypeVisibility.remove(dataType);
+    d->_dataTypeLists[identifier].clear();
+    d->_dataTypeLists.remove(identifier);
+    d->_dataTypeVisibility.remove(identifier);
 }
 
 
@@ -285,16 +293,23 @@ void DataStructure::setReadOnly(bool r)
 void DataStructure::remove()
 {
     disconnect();
-    foreach(const PointerList& pointerType, d->_pointerTypeLists) {
-        foreach(PointerPtr pointer,  pointerType) {
+    //remove pointers
+    foreach(const PointerList &pointerType, d->_pointerTypeLists) {
+        foreach(const PointerPtr &pointer,  pointerType) {
             pointer->remove();
         }
     }
-    foreach(const DataList& dataType, d->_dataTypeLists) {
-        foreach(DataPtr data, dataType) {
+    d->_pointerTypeLists.clear();
+
+
+    //remove data elements
+    foreach(const DataList &dataType, d->_dataTypeLists) {
+        foreach(const DataPtr &data, dataType) {
             data->remove();
         }
     }
+    d->_dataTypeLists.clear();
+
     d->_document->remove(getDataStructure());
 }
 
@@ -425,7 +440,7 @@ DataPtr DataStructure::getData(int uniqueIdentifier)
 void DataStructure::remove(DataPtr data)
 {
     //Note: important for resize: remove node before emit resizeRequest
-    Document *doc = DocumentManager::self()->activeDocument();
+    Document *doc = DocumentManager::self().activeDocument();
 
     if (doc != 0) {
         qreal xCenter = (doc->left() + doc->right() )/2;
@@ -499,7 +514,7 @@ void DataStructure::setName(const QString& s)
 void DataStructure::addDynamicProperty(const QString& property, const QVariant& value)
 {
     if (!Document::isValidIdentifier(property)) {
-        kWarning() << "Property identifier is not valid: aborting";
+        kWarning() << "Property identifier \"" << property << "\" is not valid: aborting";
         return;
     }
     setProperty(property.toAscii(), value);
@@ -513,7 +528,7 @@ void DataStructure::removeDynamicProperty(const QString& property)
 void DataStructure::renameDynamicProperty(const QString& oldName, const QString& newName)
 {
     if (!Document::isValidIdentifier(newName)) {
-        kWarning() << "Property identifier is not valid: aborting";
+        kWarning() << "Property identifier \"" << newName << "\" is not valid: aborting";
         return;
     }
     setProperty(newName.toStdString().c_str(), property(oldName.toStdString().c_str()));
